api.currentuser.v1.test_helpers.picture.get_profile_picture — Argus-Toolbelt 1.0 documentation

# Source code for api.currentuser.v1.test_helpers.picture.get_profile_picture

    def success(function):
        """Mock https://portal.mnemonic.no/web/api/currentuser/v1/picture, respond with HTTP 200"""
        import requests_mock
        from argus_api.helpers.tests import fake_response
        def mock_response(*args, **kwargs):
            with requests_mock.Mocker(real_http=True) as mock:
                mock.register_uri(
                    "GET",
                    r"https://portal.mnemonic.no/web/api/currentuser/v1/picture",
                    status_code=200,
                    json=fake_response({})
                )
                return function(*args, **kwargs)
            return mock_response
        return decorator

    def unauthorized(function):
        """Mock https://portal.mnemonic.no/web/api/currentuser/v1/picture, respond with HTTP 401"""
        import requests_mock
        from argus_api.helpers.tests import fake_response
        def mock_response(*args, **kwargs):
            with requests_mock.Mocker(real_http=True) as mock:
                mock.register_uri(
                    "GET",
                    r"https://portal.mnemonic.no/web/api/currentuser/v1/picture",
                    status_code=401,
                    json=None
                )
                return function(*args, **kwargs)
            return mock_response
        return decorator

    def forbidden(function):
        """Mock https://portal.mnemonic.no/web/api/currentuser/v1/picture, respond with HTTP 403"""
        import requests_mock
        from argus_api.helpers.tests import fake_response
        def mock_response(*args, **kwargs):
            with requests_mock.Mocker(real_http=True) as mock:
                mock.register_uri(
                    "GET",
                    r"https://portal.mnemonic.no/web/api/currentuser/v1/picture",
                    status_code=403,
                    json=None
                )
                return function(*args, **kwargs)
            return mock_response
        return decorator

    def not_found(function):
        """Mock https://portal.mnemonic.no/web/api/currentuser/v1/picture, respond with HTTP 404"""
        import requests_mock
        from argus_api.helpers.tests import fake_response
        def mock_response(*args, **kwargs):
            with requests_mock.Mocker(real_http=True) as mock:
                mock.register_uri(
                    "GET",
                    r"https://portal.mnemonic.no/web/api/currentuser/v1/picture",
                    status_code=404,
                    json=None
                )
                return function(*args, **kwargs)
            return mock_response
        return decorator